# explanatory notebooks

This series of notebooks illustrates the 

Robust inference of subcellular objects:

- 1️⃣. [Infer ***cellmask***](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/01_infer_cellmask.ipynb)
- 2️⃣. [infer ***nuclei*** ](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/02_infer_nuclei.ipynb)
- 3️⃣. [Infer ***cytoplasm***](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/03_infer_cytoplasm.ipynb)
- 4️⃣. [Infer ***lysosome***](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/04_infer_lysosome.ipynb)
- 5️⃣. [Infer ***mitochondria***](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/05_infer_mitochondria.ipynb)
- 6️⃣. [Infer ***golgi*** complex](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/06_golgi.ipynb)
- 7️⃣. [Infer ***peroxisome***](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/07_peroxisome.ipynb)
- 8️⃣. [Infer ***endoplasmic reticulum***](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/08_infer_ER.ipynb)
- 9️⃣. [Infer ***lipid body***](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/09_lipid_droplet.ipynb) 


other examples

- 1️⃣4️⃣. [final workflow](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/14_final_workflow.ipynb)
- 1️⃣1️⃣. [batch process](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/11_batch_process.ipynb)


basics

- 0️⃣0️⃣.1️⃣. [framework overview](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/00.0_framework_overview.ipynb)
- 0️⃣0️⃣.1️⃣. [pipeline setup](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/00.1_pipeline_setup.ipynb)


stats

- 1️⃣0️⃣. [regionprop stats](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/10_regionprops.ipynb)

workflow .json composition

- 1️⃣2️⃣. [function prototoypes](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/12_fn_prototypes_json.ipynb)
- 1️⃣3️⃣. [workflow defs](https://github.com/ndcn/infer-subc/blob/68976b1f56e0f2bac191e297077b8378c663793c/notebooks/13_workflow_defs_json.ipynb)

